[jbossws-commits] JBossWS SVN: r2255 - in branches/jbossws-1.2.0: build/ant-import and 15 other directories.

jbossws-commits at lists.jboss.org jbossws-commits at lists.jboss.org
Fri Feb 2 12:33:49 EST 2007


Author: thomas.diesler at jboss.com
Date: 2007-02-02 12:33:49 -0500 (Fri, 02 Feb 2007)
New Revision: 2255

Added:
   branches/jbossws-1.2.0/integration-tomcat/src/main/resources/tomcat-users.xml
Removed:
   branches/jbossws-1.2.0/jbossws-tests/src/main/resources/jaxrpc/wsse/keystore.password
   branches/jbossws-1.2.0/jbossws-tests/src/main/resources/jaxrpc/wsse/wsse.keystore
   branches/jbossws-1.2.0/jbossws-tests/src/main/resources/jaxrpc/wsse/wsse.truststore
   branches/jbossws-1.2.0/jbossws-tests/src/main/resources/jaxws/samples/webservice/WEB-INF01/jboss-web.xml
   branches/jbossws-1.2.0/jbossws-tests/src/main/resources/jaxws/samples/webservice/WEB-INF02/jboss-web.xml
   branches/jbossws-1.2.0/jbossws-tests/src/main/resources/jaxws/samples/webservice/WEB-INF03/jboss-web.xml
Modified:
   branches/jbossws-1.2.0/build/ant-import/build-samples.xml
   branches/jbossws-1.2.0/build/ant-import/build-setup.xml
   branches/jbossws-1.2.0/build/ant.properties.example
   branches/jbossws-1.2.0/integration-tomcat/build.xml
   branches/jbossws-1.2.0/integration-tomcat/src/main/resources/log4j.xml
   branches/jbossws-1.2.0/jbossws-core/src/main/java/javax/xml/ws/handler/MessageContext.java
   branches/jbossws-1.2.0/jbossws-core/src/main/java/org/jboss/ws/core/jaxws/WebServiceContextJSE.java
   branches/jbossws-1.2.0/jbossws-core/src/main/resources/samples/ant-import/build-thirdparty.xml
   branches/jbossws-1.2.0/jbossws-core/src/main/resources/samples/ant.properties.example
   branches/jbossws-1.2.0/jbossws-core/src/main/resources/samples/build.xml
   branches/jbossws-1.2.0/jbossws-tests/ant-import/build-samples-jaxws.xml
   branches/jbossws-1.2.0/jbossws-tests/build.xml
   branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/EJB21Bean01.java
   branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/EJB21Bean02.java
   branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/EJB3Bean01.java
   branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/EJB3Bean02.java
   branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/EndpointInterface03.java
   branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/JSR181WebServiceBase.java
   branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/JSR181WebServiceEJB3TestCase.java
   branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/JSR181WebServiceJSETestCase.java
   branches/jbossws-1.2.0/jbossws-tests/src/main/resources/jaxrpc/wsse/store-pass-encrypt-class-cmd/jboss-wsse-server.xml
   branches/jbossws-1.2.0/jbossws-tests/src/main/resources/tests-tomcat-excludes.txt
Log:
WebServiceContextJSE delegates to HTTPServletREquest instead of JBossSX
Deploy-tomcat copies tomcat-users.xml
Remove dependency on jboss-web.xml for jaxws samples
Remove duplicated keystore/truststore



Modified: branches/jbossws-1.2.0/build/ant-import/build-samples.xml
===================================================================
--- branches/jbossws-1.2.0/build/ant-import/build-samples.xml	2007-02-02 14:40:37 UTC (rev 2254)
+++ branches/jbossws-1.2.0/build/ant-import/build-samples.xml	2007-02-02 17:33:49 UTC (rev 2255)
@@ -28,7 +28,7 @@
         <include name="build.xml"/>
       </fileset>
     </copy>
-    <copy file="${build.src.samples.dir}/ant.properties.example" tofile="${build.src.samples.dir}/ant.properties"/>
+    <!--copy file="${build.src.samples.dir}/ant.properties.example" tofile="${build.src.samples.dir}/ant.properties"/-->
 
     <copy todir="${build.src.samples.dir}">
       <fileset dir="${core.samples.dir}">
@@ -63,10 +63,11 @@
     <mkdir dir="${build.src.samples.dir}/lib"/>
     <copy todir="${build.src.samples.dir}/lib">
       <fileset dir="${core.output.lib.dir}">
+        <include name="jbossws-core.jar"/>
+        <include name="jbossws-client.jar"/>
         <include name="jboss-jaxrpc.jar"/>
         <include name="jboss-jaxws.jar"/>
         <include name="jboss-saaj.jar"/>
-        <include name="jbossws-client.jar"/>
       </fileset>
       <fileset dir="${jboss50.output.lib.dir}">
         <include name="jbossws-jboss50-integration.jar"/>

Modified: branches/jbossws-1.2.0/build/ant-import/build-setup.xml
===================================================================
--- branches/jbossws-1.2.0/build/ant-import/build-setup.xml	2007-02-02 14:40:37 UTC (rev 2254)
+++ branches/jbossws-1.2.0/build/ant-import/build-setup.xml	2007-02-02 17:33:49 UTC (rev 2255)
@@ -57,10 +57,11 @@
   <property name="jboss40.server.deploy" value="${jboss40.server}/deploy"/>
   <property name="jboss40.thirdparty" value="${jboss40.home}/../../../thirdparty"/>
   
-  <property name="tomcat.webapps.dir" value="${tomcat.home}/webapps"/>
+  <property name="tomcat.conf.dir" value="${tomcat.home}/conf"/>
   <property name="tomcat.common.dir" value="${tomcat.home}/common"/>
   <property name="tomcat.common.classes" value="${tomcat.home}/common/classes"/>
   <property name="tomcat.common.lib" value="${tomcat.home}/common/lib"/>
+  <property name="tomcat.webapps.dir" value="${tomcat.home}/webapps"/>
 
   <available property="jboss50.available" file="${jboss50.client}/jboss-client.jar"/>
   <available property="jboss42.available" file="${jboss42.client}/jboss-client.jar"/>

Modified: branches/jbossws-1.2.0/build/ant.properties.example
===================================================================
--- branches/jbossws-1.2.0/build/ant.properties.example	2007-02-02 14:40:37 UTC (rev 2254)
+++ branches/jbossws-1.2.0/build/ant.properties.example	2007-02-02 17:33:49 UTC (rev 2255)
@@ -9,7 +9,7 @@
 #jboss40.home=/home/tdiesler/svn/jbossas/branches/Branch_4_0/build/output/jboss-4.0.5.SP1-ejb3
 
 # The JBoss server under test. This can be [jboss50|jboss42|jboss40|tomcat]
-jbossws.integration.target=jboss50
+jbossws.integration.target=jboss42
 
 # The JBoss server instance
 jboss.server.instance=default

Modified: branches/jbossws-1.2.0/integration-tomcat/build.xml
===================================================================
--- branches/jbossws-1.2.0/integration-tomcat/build.xml	2007-02-02 14:40:37 UTC (rev 2254)
+++ branches/jbossws-1.2.0/integration-tomcat/build.xml	2007-02-02 17:33:49 UTC (rev 2255)
@@ -99,7 +99,7 @@
         <include name="META-INF/standard-jaxws-client-config.xml"/>
         <include name="META-INF/standard-jaxws-endpoint-config.xml"/>
       </fileset>
-      <webinf dir="${tomcat.resources.dir}/jbossws.war/WEB-INF">
+      <webinf dir="${tomcat.resources.dir}">
         <include name="log4j.xml"/>
       </webinf>
     </war>
@@ -110,6 +110,7 @@
     <!-- Build jbossws-thirdparty.jar -->
     <mkdir dir="${tomcat.output.lib.dir}/build"/>
     <unjar dest="${tomcat.output.lib.dir}/build" src="${thirdparty.dir}/ejb3.deployer/jboss-ejb3x.jar"/>
+    <unjar dest="${tomcat.output.lib.dir}/build" src="${thirdparty.dir}/commons-logging.jar"/>
     <unjar dest="${tomcat.output.lib.dir}/build" src="${thirdparty.dir}/concurrent.jar"/>
     <unjar dest="${tomcat.output.lib.dir}/build" src="${thirdparty.dir}/jaxb-api.jar"/>
     <unjar dest="${tomcat.output.lib.dir}/build" src="${thirdparty.dir}/jaxb-impl.jar"/>
@@ -124,6 +125,7 @@
     <unjar dest="${tomcat.output.lib.dir}/build" src="${thirdparty.dir}/jboss-xml-binding.jar"/>
     <unjar dest="${tomcat.output.lib.dir}/build" src="${thirdparty.dir}/javassist.jar"/>
     <unjar dest="${tomcat.output.lib.dir}/build" src="${thirdparty.dir}/log4j.jar"/>
+    <unjar dest="${tomcat.output.lib.dir}/build" src="${thirdparty.dir}/stax-api.jar"/>
     <unjar dest="${tomcat.output.lib.dir}/build" src="${thirdparty.dir}/wsdl4j.jar"/>
     <unjar dest="${tomcat.output.lib.dir}/build" src="${thirdparty.dir}/xmlsec.jar"/>
     <jar jarfile="${tomcat.output.lib.dir}/jbossws-thirdparty.jar" manifest="${etc.dir}/default.mf">
@@ -145,6 +147,11 @@
         <include name="xercesImpl.jar"/>
       </fileset>
     </copy>
+    <copy todir="${tomcat.conf.dir}" overwrite="true">
+      <fileset dir="${tomcat.resources.dir}">
+        <include name="tomcat-users.xml"/>
+      </fileset>
+    </copy>
     <copy todir="${tomcat.common.classes}" overwrite="true">
       <fileset dir="${tomcat.resources.dir}">
         <include name="log4j.xml"/>

Modified: branches/jbossws-1.2.0/integration-tomcat/src/main/resources/log4j.xml
===================================================================
--- branches/jbossws-1.2.0/integration-tomcat/src/main/resources/log4j.xml	2007-02-02 14:40:37 UTC (rev 2254)
+++ branches/jbossws-1.2.0/integration-tomcat/src/main/resources/log4j.xml	2007-02-02 17:33:49 UTC (rev 2255)
@@ -56,14 +56,27 @@
     <priority value="DEBUG"/>
   </category>
 
-   <category name="org.jboss.remoting">
+  <category name="org.apache.catalina">
     <priority value="INFO"/>
   </category>
 
-  <!-- Enable SOAP message tracing -->
+  <category name="org.apache.commons">
+    <priority value="INFO"/>
+  </category>
+
+  <category name="org.apache.jasper">
+    <priority value="INFO"/>
+  </category>
+
+  <category name="org.jboss.remoting">
+    <priority value="INFO"/>
+  </category>
+
+  <!-- Enable SOAP message tracing 
   <category name="jbossws.SOAPMessage">
    <priority value="TRACE" class="org.jboss.logging.XLevel"/>
   </category>
+  -->
 
   <!-- ======================= -->
   <!-- Setup the Root category -->

Added: branches/jbossws-1.2.0/integration-tomcat/src/main/resources/tomcat-users.xml
===================================================================
--- branches/jbossws-1.2.0/integration-tomcat/src/main/resources/tomcat-users.xml	                        (rev 0)
+++ branches/jbossws-1.2.0/integration-tomcat/src/main/resources/tomcat-users.xml	2007-02-02 17:33:49 UTC (rev 2255)
@@ -0,0 +1,10 @@
+<?xml version='1.0' encoding='utf-8'?>
+<tomcat-users>
+  <!-- Security realm for jbossws sample tests -->
+  <role rolename="friend"/>
+  <user username="kermit" password="thefrog" roles="friend"/>
+  
+  <!-- Security realm for jbossws sample deployment -->
+  <role rolename="manager"/>
+  <user username="manager" password="manager" roles="manager"/>
+</tomcat-users>


Property changes on: branches/jbossws-1.2.0/integration-tomcat/src/main/resources/tomcat-users.xml
___________________________________________________________________
Name: svn:keywords
   + Id Revision
Name: svn:eol-style
   + LF

Modified: branches/jbossws-1.2.0/jbossws-core/src/main/java/javax/xml/ws/handler/MessageContext.java
===================================================================
--- branches/jbossws-1.2.0/jbossws-core/src/main/java/javax/xml/ws/handler/MessageContext.java	2007-02-02 14:40:37 UTC (rev 2254)
+++ branches/jbossws-1.2.0/jbossws-core/src/main/java/javax/xml/ws/handler/MessageContext.java	2007-02-02 17:33:49 UTC (rev 2255)
@@ -37,168 +37,154 @@
  *
  * @since JAX-WS 2.0
  */
-public interface MessageContext extends Map<String, Object> {
-    
-    /**
-     * Standard property: message direction, <code>true</code> for
-     * outbound messages, <code>false</code> for inbound.
-     * <p>Type: boolean
-     */
-    public static final String MESSAGE_OUTBOUND_PROPERTY =
-            "javax.xml.ws.handler.message.outbound";
-    
-    /**
-     * Standard property: Map of attachments to a message for the inbound
-     * message, key is  the MIME Content-ID, value is a DataHandler.
-     * <p>Type: java.util.Map<String,DataHandler>
-     */
-    public static final String INBOUND_MESSAGE_ATTACHMENTS =
-            "javax.xml.ws.binding.attachments.inbound";
-    
-    /**
-     * Standard property: Map of attachments to a message for the outbound
-     * message, key is the MIME Content-ID, value is a DataHandler.
-     * <p>Type: java.util.Map<String,DataHandler>
-     */
-    public static final String OUTBOUND_MESSAGE_ATTACHMENTS =
-            "javax.xml.ws.binding.attachments.outbound";
-    
-    /**
-     * Standard property: input source for WSDL document.
-     * <p>Type: org.xml.sax.InputSource
-     */
-    public static final String WSDL_DESCRIPTION =
-            "javax.xml.ws.wsdl.description";
-    
-    /**
-     * Standard property: name of WSDL service.
-     * <p>Type: javax.xml.namespace.QName
-     */
-    public static final String WSDL_SERVICE =
-            "javax.xml.ws.wsdl.service";
-    
-    /**
-     * Standard property: name of WSDL port.
-     * <p>Type: javax.xml.namespace.QName
-     */
-    public static final String WSDL_PORT =
-            "javax.xml.ws.wsdl.port";
-    
-    /**
-     * Standard property: name of wsdl interface (2.0) or port type (1.1).
-     * <p>Type: javax.xml.namespace.QName
-     */
-    public static final String WSDL_INTERFACE =
-            "javax.xml.ws.wsdl.interface";
-    
-    /**
-     * Standard property: name of WSDL operation.
-     * <p>Type: javax.xml.namespace.QName
-     */
-    public static final String WSDL_OPERATION =
-            "javax.xml.ws.wsdl.operation";
-    
-    /**
-     * Standard property: HTTP response status code.
-     * <p>Type: java.lang.Integer
-     */
-    public static final String HTTP_RESPONSE_CODE =
-            "javax.xml.ws.http.response.code";
-    
-    /**
-     * Standard property: HTTP request headers.
-     * <p>Type: java.util.Map<java.lang.String, java.util.List<java.lang.String>>
-     */
-    public static final String HTTP_REQUEST_HEADERS =
-            "javax.xml.ws.http.request.headers";
-    
-    /**
-     * Standard property: HTTP response headers.
-     * <p>Type: java.util.Map<java.lang.String, java.util.List<java.lang.String>>
-     */
-    public static final String HTTP_RESPONSE_HEADERS =
-            "javax.xml.ws.http.response.headers";
-    
-    /**
-     * Standard property: HTTP request method.
-     * <p>Type: java.lang.String
-     */
-    public static final String HTTP_REQUEST_METHOD =
-            "javax.xml.ws.http.request.method";
-    
-    /**
-     * Standard property: servlet request object.
-     * <p>Type: javax.servlet.http.HttpServletRequest
-     */
-    public static final String SERVLET_REQUEST =
-            "javax.xml.ws.servlet.request";
-    
-    /**
-     * Standard property: servlet response object.
-     * <p>Type: javax.servlet.http.HttpServletResponse
-     */
-    public static final String SERVLET_RESPONSE =
-            "javax.xml.ws.servlet.response";
-    
-    /**
-     * Standard property: servlet context object.
-     * <p>Type: javax.servlet.ServletContext
-     */
-    public static final String SERVLET_CONTEXT =
-            "javax.xml.ws.servlet.context";
-    
-    /**
-     * Standard property: Query string for request.
-     * <p>Type: String
-     **/
-    public static final String QUERY_STRING =
-            "javax.xml.ws.http.request.querystring";
-    
-    /**
-     * Standard property: Request Path Info
-     * <p>Type: String
-     */
-    public static final String PATH_INFO =
-            "javax.xml.ws.http.request.pathinfo";
-    
-    /**
-     * Standard property: WS Addressing Reference Parameters.
-     * The list MUST include all SOAP headers marked with the
-     * wsa:IsReferenceParameter="true" attribute.
-     * <p>Type: List<Element>
-     *
-     * @since JAX-WS 2.1
-     */
-    public static final String REFERENCE_PARAMETERS =
-            "javax.xml.ws.reference.parameters";
-    
-    /**
-     * Property scope. Properties scoped as <code>APPLICATION</code> are
-     * visible to handlers,
-     * client applications and service endpoints; properties scoped as
-     * <code>HANDLER</code>
-     * are only normally visible to handlers.
-     */
-    public enum Scope {APPLICATION, HANDLER};
-    
-    /** 
-     * Sets the scope of a property.
-     *
-     * @param name Name of the property associated with the
-     *             <code>MessageContext</code>
-     * @param scope Desired scope of the property
-     * @throws java.lang.IllegalArgumentException if an illegal
-     *             property name is specified
-     */
-    public void setScope(String name,  Scope scope);
-    
-    /** 
-     * Gets the scope of a property.
-     *
-     * @param name Name of the property
-     * @return Scope of the property
-     * @throws java.lang.IllegalArgumentException if a non-existant
-     *             property name is specified
-     */
-    public Scope getScope(String  name);
+public interface MessageContext extends Map<String, Object>
+{
+
+   /**
+    * Standard property: message direction, <code>true</code> for
+    * outbound messages, <code>false</code> for inbound.
+    * <p>Type: boolean
+    */
+   public static final String MESSAGE_OUTBOUND_PROPERTY = "javax.xml.ws.handler.message.outbound";
+
+   /**
+    * Standard property: Map of attachments to a message for the inbound
+    * message, key is  the MIME Content-ID, value is a DataHandler.
+    * <p>Type: java.util.Map<String,DataHandler>
+    */
+   public static final String INBOUND_MESSAGE_ATTACHMENTS = "javax.xml.ws.binding.attachments.inbound";
+
+   /**
+    * Standard property: Map of attachments to a message for the outbound
+    * message, key is the MIME Content-ID, value is a DataHandler.
+    * <p>Type: java.util.Map<String,DataHandler>
+    */
+   public static final String OUTBOUND_MESSAGE_ATTACHMENTS = "javax.xml.ws.binding.attachments.outbound";
+
+   /**
+    * Standard property: input source for WSDL document.
+    * <p>Type: org.xml.sax.InputSource
+    */
+   public static final String WSDL_DESCRIPTION = "javax.xml.ws.wsdl.description";
+
+   /**
+    * Standard property: name of WSDL service.
+    * <p>Type: javax.xml.namespace.QName
+    */
+   public static final String WSDL_SERVICE = "javax.xml.ws.wsdl.service";
+
+   /**
+    * Standard property: name of WSDL port.
+    * <p>Type: javax.xml.namespace.QName
+    */
+   public static final String WSDL_PORT = "javax.xml.ws.wsdl.port";
+
+   /**
+    * Standard property: name of wsdl interface (2.0) or port type (1.1).
+    * <p>Type: javax.xml.namespace.QName
+    */
+   public static final String WSDL_INTERFACE = "javax.xml.ws.wsdl.interface";
+
+   /**
+    * Standard property: name of WSDL operation.
+    * <p>Type: javax.xml.namespace.QName
+    */
+   public static final String WSDL_OPERATION = "javax.xml.ws.wsdl.operation";
+
+   /**
+    * Standard property: HTTP response status code.
+    * <p>Type: java.lang.Integer
+    */
+   public static final String HTTP_RESPONSE_CODE = "javax.xml.ws.http.response.code";
+
+   /**
+    * Standard property: HTTP request headers.
+    * <p>Type: java.util.Map<java.lang.String, java.util.List<java.lang.String>>
+    */
+   public static final String HTTP_REQUEST_HEADERS = "javax.xml.ws.http.request.headers";
+
+   /**
+    * Standard property: HTTP response headers.
+    * <p>Type: java.util.Map<java.lang.String, java.util.List<java.lang.String>>
+    */
+   public static final String HTTP_RESPONSE_HEADERS = "javax.xml.ws.http.response.headers";
+
+   /**
+    * Standard property: HTTP request method.
+    * <p>Type: java.lang.String
+    */
+   public static final String HTTP_REQUEST_METHOD = "javax.xml.ws.http.request.method";
+
+   /**
+    * Standard property: servlet request object.
+    * <p>Type: javax.servlet.http.HttpServletRequest
+    */
+   public static final String SERVLET_REQUEST = "javax.xml.ws.servlet.request";
+
+   /**
+    * Standard property: servlet response object.
+    * <p>Type: javax.servlet.http.HttpServletResponse
+    */
+   public static final String SERVLET_RESPONSE = "javax.xml.ws.servlet.response";
+
+   /**
+    * Standard property: servlet context object.
+    * <p>Type: javax.servlet.ServletContext
+    */
+   public static final String SERVLET_CONTEXT = "javax.xml.ws.servlet.context";
+
+   /**
+    * Standard property: Query string for request.
+    * <p>Type: String
+    **/
+   public static final String QUERY_STRING = "javax.xml.ws.http.request.querystring";
+
+   /**
+    * Standard property: Request Path Info
+    * <p>Type: String
+    */
+   public static final String PATH_INFO = "javax.xml.ws.http.request.pathinfo";
+
+   /**
+    * Standard property: WS Addressing Reference Parameters.
+    * The list MUST include all SOAP headers marked with the
+    * wsa:IsReferenceParameter="true" attribute.
+    * <p>Type: List<Element>
+    *
+    * @since JAX-WS 2.1
+    */
+   public static final String REFERENCE_PARAMETERS = "javax.xml.ws.reference.parameters";
+
+   /**
+    * Property scope. Properties scoped as <code>APPLICATION</code> are
+    * visible to handlers,
+    * client applications and service endpoints; properties scoped as
+    * <code>HANDLER</code>
+    * are only normally visible to handlers.
+    */
+   public enum Scope
+   {
+      APPLICATION, HANDLER
+   };
+
+   /** 
+    * Sets the scope of a property.
+    *
+    * @param name Name of the property associated with the
+    *             <code>MessageContext</code>
+    * @param scope Desired scope of the property
+    * @throws java.lang.IllegalArgumentException if an illegal
+    *             property name is specified
+    */
+   public void setScope(String name, Scope scope);
+
+   /** 
+    * Gets the scope of a property.
+    *
+    * @param name Name of the property
+    * @return Scope of the property
+    * @throws java.lang.IllegalArgumentException if a non-existant
+    *             property name is specified
+    */
+   public Scope getScope(String name);
 }

Modified: branches/jbossws-1.2.0/jbossws-core/src/main/java/org/jboss/ws/core/jaxws/WebServiceContextJSE.java
===================================================================
--- branches/jbossws-1.2.0/jbossws-core/src/main/resources/samples/ant-import/build-thirdparty.xml	2007-02-02 14:40:37 UTC (rev 2254)
+++ branches/jbossws-1.2.0/jbossws-core/src/main/resources/samples/ant-import/build-thirdparty.xml	2007-02-02 17:33:49 UTC (rev 2255)
@@ -61,22 +61,14 @@
       <pathelement location="${thirdparty.dir}/jaxb-api.jar"/>
       <pathelement location="${thirdparty.dir}/jaxb-impl.jar"/>
       <pathelement location="${thirdparty.dir}/jboss-common.jar"/>
-      <pathelement location="${thirdparty.dir}/jboss-dependency.jar"/>
       <pathelement location="${thirdparty.dir}/jboss-j2ee.jar"/>
       <pathelement location="${thirdparty.dir}/jboss-logging-spi.jar"/>
-      <pathelement location="${thirdparty.dir}/jboss-microcontainer.jar"/>
-      <pathelement location="${thirdparty.dir}/jboss-remoting.jar"/>
       <pathelement location="${thirdparty.dir}/jboss-xml-binding.jar"/>
       <pathelement location="${thirdparty.dir}/jbosssx-client.jar"/>
       <pathelement location="${thirdparty.dir}/mail.jar"/>
       <pathelement location="${thirdparty.dir}/servlet-api.jar"/>
       <pathelement location="${thirdparty.dir}/stax-api.jar"/>
       <pathelement location="${thirdparty.dir}/wsdl4j.jar"/>
-      <pathelement location="${thirdparty.dir}/wstx.jar"/>
-      <pathelement location="${thirdparty.dir}/getopt.jar"/>
-      <pathelement location="${thirdparty.dir}/xmlsec.jar"/>
-      <pathelement location="${thirdparty.dir}/xercesImpl.jar"/>
-      <pathelement location="${thirdparty.dir}/xalan.jar"/>
     </path>
 
   </target>

Modified: branches/jbossws-1.2.0/jbossws-core/src/main/resources/samples/ant.properties.example
===================================================================
--- branches/jbossws-1.2.0/jbossws-core/src/main/resources/samples/ant.properties.example	2007-02-02 14:40:37 UTC (rev 2254)
+++ branches/jbossws-1.2.0/jbossws-core/src/main/resources/samples/ant.properties.example	2007-02-02 17:33:49 UTC (rev 2255)
@@ -7,7 +7,7 @@
 jboss40.home=/home/tdiesler/svn/jbossas/branches/Branch_4_0/build/output/jboss-4.0.5.SP1-ejb3
 
 # The JBoss server under test. This can be [jboss50|jboss42|jboss40|tomcat]
-jbossws.integration.target=jboss50
+jbossws.integration.target=jboss42
 
 # The JBoss server instance
 jboss.server.instance=default
@@ -18,8 +18,8 @@
 tomcat.manager.password=manager
 
 # JBoss Repository
-jboss.repository=file:/home/tdiesler/cvs/jboss.local.repository
-#jboss.repository=http://repository.jboss.com
+#jboss.repository=file:/home/tdiesler/cvs/jboss.local.repository
+jboss.repository=http://repository.jboss.com
 
 # Force thirdparty HTTP get
 #force.thirdparty.get=true

Modified: branches/jbossws-1.2.0/jbossws-core/src/main/resources/samples/build.xml
===================================================================
--- branches/jbossws-1.2.0/jbossws-core/src/main/resources/samples/build.xml	2007-02-02 14:40:37 UTC (rev 2254)
+++ branches/jbossws-1.2.0/jbossws-core/src/main/resources/samples/build.xml	2007-02-02 17:33:49 UTC (rev 2255)
@@ -151,6 +151,7 @@
     
     <!-- The combined compile classpath -->
     <path id="jbossws.jars.classpath">
+      <pathelement location="${tests.lib.dir}/jbossws-core.jar"/>
       <pathelement location="${tests.lib.dir}/jbossws-client.jar"/>
       <pathelement location="${tests.lib.dir}/jboss-jaxrpc.jar"/>
       <pathelement location="${tests.lib.dir}/jboss-jaxws.jar"/>
@@ -320,7 +321,10 @@
 	  <!-- generate mapping artifacts -->
     <taskdef name="wstools" classname="org.jboss.ws.tools.ant.wstools">
       <classpath refid="core.classpath"/>
-      <classpath location="${tests.lib.dir}/jbossws-client.jar"/>
+      <classpath location="${tests.lib.dir}/jbossws-core.jar"/>
+      <classpath location="${tests.lib.dir}/jboss-jaxrpc.jar"/>
+      <classpath location="${tests.lib.dir}/jboss-jaxws.jar"/>
+      <classpath location="${tests.lib.dir}/jboss-saaj.jar"/>
       <classpath location="${thirdparty.dir}/concurrent.jar"/>
       <classpath location="${tests.output.dir}/classes"/>
       <classpath location="${tests.output.dir}"/>
@@ -405,8 +409,8 @@
       <sysproperty key="tomcat.home" value="${tomcat.home}"/>
       <sysproperty key="tomcat.manager.password" value="${tomcat.manager.password}"/>
       <sysproperty key="tomcat.manager.username" value="${tomcat.manager.username}"/>
-      <sysproperty key="org.jboss.ws.wsse.keyStore" value="${tests.resources.dir}/jaxrpc/wsse/wsse.keystore"/>
-      <sysproperty key="org.jboss.ws.wsse.trustStore" value="${tests.resources.dir}/jaxrpc/wsse/wsse.truststore"/>
+      <sysproperty key="org.jboss.ws.wsse.keyStore" value="${tests.resources.dir}/jaxrpc/samples/wssecurity/wsse.keystore"/>
+      <sysproperty key="org.jboss.ws.wsse.trustStore" value="${tests.resources.dir}/jaxrpc/samples/wssecurity/wsse.truststore"/>
       <sysproperty key="org.jboss.ws.wsse.keyStorePassword" value="jbossws"/>
       <sysproperty key="org.jboss.ws.wsse.trustStorePassword" value="jbossws"/>
       <sysproperty key="org.jboss.ws.wsse.keyStoreType" value="jks"/>
@@ -446,8 +450,8 @@
       <sysproperty key="tomcat.manager.username" value="${tomcat.manager.username}"/>
       <!--
       http://jira.jboss.com/jira/browse/JBWS-917
-      <sysproperty key="javax.net.ssl.keyStore" value="${tests.resources.dir}/jaxrpc/wsse/wsse.keystore"/>
-      <sysproperty key="javax.net.ssl.trustStore" value="${tests.resources.dir}/jaxrpc/wsse/wsse.truststore"/>
+      <sysproperty key="javax.net.ssl.keyStore" value="${tests.resources.dir}/jaxrpc/samples/wssecurity/wsse.keystore"/>
+      <sysproperty key="javax.net.ssl.trustStore" value="${tests.resources.dir}/jaxrpc/samples/wssecurity/wsse.truststore"/>
       <sysproperty key="javax.net.ssl.keyStorePassword" value="jbossws"/>
       <sysproperty key="javax.net.ssl.trustStorePassword" value="jbossws"/>
       <sysproperty key="javax.net.ssl.keyStoreType" value="jks"/>
@@ -455,8 +459,8 @@
       -->
       <!-- HTTPS hostname wrong:  should be <localhost> -->
       <sysproperty key="org.jboss.security.ignoreHttpsHost" value="true"/>
-      <sysproperty key="org.jboss.ws.wsse.keyStore" value="${tests.resources.dir}/jaxrpc/wsse/wsse.keystore"/>
-      <sysproperty key="org.jboss.ws.wsse.trustStore" value="${tests.resources.dir}/jaxrpc/wsse/wsse.truststore"/>
+      <sysproperty key="org.jboss.ws.wsse.keyStore" value="${tests.resources.dir}/jaxrpc/samples/wssecurity/wsse.keystore"/>
+      <sysproperty key="org.jboss.ws.wsse.trustStore" value="${tests.resources.dir}/jaxrpc/samples/wssecurity/wsse.truststore"/>
       <sysproperty key="org.jboss.ws.wsse.keyStorePassword" value="jbossws"/>
       <sysproperty key="org.jboss.ws.wsse.trustStorePassword" value="jbossws"/>
       <sysproperty key="org.jboss.ws.wsse.keyStoreType" value="jks"/>

Modified: branches/jbossws-1.2.0/jbossws-tests/ant-import/build-samples-jaxws.xml
===================================================================
--- branches/jbossws-1.2.0/jbossws-tests/ant-import/build-samples-jaxws.xml	2007-02-02 14:40:37 UTC (rev 2254)
+++ branches/jbossws-1.2.0/jbossws-tests/ant-import/build-samples-jaxws.xml	2007-02-02 17:33:49 UTC (rev 2255)
@@ -256,16 +256,12 @@
       <classes dir="${tests.output.dir}/classes">
         <include name="org/jboss/test/ws/jaxws/samples/webservice/JSEBean01.class"/>
       </classes>
-      <webinf dir="${tests.output.dir}/resources/jaxws/samples/webservice/WEB-INF01">
-        <include name="jboss-web.xml"/>
-      </webinf>
     </war>
     <war warfile="${tests.output.dir}/libs/jaxws-samples-webservice02-jse.war" webxml="${tests.output.dir}/resources/jaxws/samples/webservice/WEB-INF02/web.xml">
       <classes dir="${tests.output.dir}/classes">
         <include name="org/jboss/test/ws/jaxws/samples/webservice/JSEBean02.class"/>
       </classes>
       <webinf dir="${tests.output.dir}/resources/jaxws/samples/webservice/WEB-INF02">
-        <include name="jboss-web.xml"/>
         <include name="wsdl/**"/>
       </webinf>
     </war>
@@ -274,9 +270,6 @@
         <include name="org/jboss/test/ws/jaxws/samples/webservice/JSEBean03.class"/>
         <include name="org/jboss/test/ws/jaxws/samples/webservice/EndpointInterface03.class"/>
       </classes>
-      <webinf dir="${tests.output.dir}/resources/jaxws/samples/webservice/WEB-INF03">
-        <include name="jboss-web.xml"/>
-      </webinf>
     </war>
     <jar jarfile="${tests.output.dir}/libs/jaxws-samples-webservice01-ejb3.jar">
       <fileset dir="${tests.output.dir}/classes">

Modified: branches/jbossws-1.2.0/jbossws-tests/build.xml
===================================================================
--- branches/jbossws-1.2.0/jbossws-tests/build.xml	2007-02-02 14:40:37 UTC (rev 2254)
+++ branches/jbossws-1.2.0/jbossws-tests/build.xml	2007-02-02 17:33:49 UTC (rev 2255)
@@ -435,8 +435,8 @@
       <sysproperty key="tomcat.home" value="${tomcat.home}"/>
       <sysproperty key="tomcat.manager.password" value="${tomcat.manager.password}"/>
       <sysproperty key="tomcat.manager.username" value="${tomcat.manager.username}"/>
-      <sysproperty key="org.jboss.ws.wsse.keyStore" value="${tests.resources.dir}/jaxrpc/wsse/wsse.keystore"/>
-      <sysproperty key="org.jboss.ws.wsse.trustStore" value="${tests.resources.dir}/jaxrpc/wsse/wsse.truststore"/>
+      <sysproperty key="org.jboss.ws.wsse.keyStore" value="${tests.resources.dir}/jaxrpc/samples/wssecurity/wsse.keystore"/>
+      <sysproperty key="org.jboss.ws.wsse.trustStore" value="${tests.resources.dir}/jaxrpc/samples/wssecurity/wsse.truststore"/>
       <sysproperty key="org.jboss.ws.wsse.keyStorePassword" value="jbossws"/>
       <sysproperty key="org.jboss.ws.wsse.trustStorePassword" value="jbossws"/>
       <sysproperty key="org.jboss.ws.wsse.keyStoreType" value="jks"/>
@@ -476,8 +476,8 @@
       <sysproperty key="tomcat.manager.username" value="${tomcat.manager.username}"/>
       <!--
       http://jira.jboss.com/jira/browse/JBWS-917
-      <sysproperty key="javax.net.ssl.keyStore" value="${tests.resources.dir}/jaxrpc/wsse/wsse.keystore"/>
-      <sysproperty key="javax.net.ssl.trustStore" value="${tests.resources.dir}/jaxrpc/wsse/wsse.truststore"/>
+      <sysproperty key="javax.net.ssl.keyStore" value="${tests.resources.dir}/jaxrpc/samples/wssecurity/wsse.keystore"/>
+      <sysproperty key="javax.net.ssl.trustStore" value="${tests.resources.dir}/jaxrpc/samples/wssecurity/wsse.truststore"/>
       <sysproperty key="javax.net.ssl.keyStorePassword" value="jbossws"/>
       <sysproperty key="javax.net.ssl.trustStorePassword" value="jbossws"/>
       <sysproperty key="javax.net.ssl.keyStoreType" value="jks"/>
@@ -485,8 +485,8 @@
       -->
       <!-- HTTPS hostname wrong:  should be <localhost> -->
       <sysproperty key="org.jboss.security.ignoreHttpsHost" value="true"/>
-      <sysproperty key="org.jboss.ws.wsse.keyStore" value="${tests.resources.dir}/jaxrpc/wsse/wsse.keystore"/>
-      <sysproperty key="org.jboss.ws.wsse.trustStore" value="${tests.resources.dir}/jaxrpc/wsse/wsse.truststore"/>
+      <sysproperty key="org.jboss.ws.wsse.keyStore" value="${tests.resources.dir}/jaxrpc/samples/wssecurity/wsse.keystore"/>
+      <sysproperty key="org.jboss.ws.wsse.trustStore" value="${tests.resources.dir}/jaxrpc/samples/wssecurity/wsse.truststore"/>
       <sysproperty key="org.jboss.ws.wsse.keyStorePassword" value="jbossws"/>
       <sysproperty key="org.jboss.ws.wsse.trustStorePassword" value="jbossws"/>
       <sysproperty key="org.jboss.ws.wsse.keyStoreType" value="jks"/>

Modified: branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/EJB21Bean01.java
===================================================================
--- branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/EJB21Bean01.java	2007-02-02 14:40:37 UTC (rev 2254)
+++ branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/EJB21Bean01.java	2007-02-02 17:33:49 UTC (rev 2255)
@@ -40,7 +40,7 @@
  */
 @WebService(name = "EndpointInterface", targetNamespace = "http://www.openuri.org/2004/04/HelloWorld", serviceName = "TestService")
 @SOAPBinding(style = SOAPBinding.Style.RPC)
- at WebContext(contextRoot="/jsr181", urlPattern="/*")
+ at WebContext(urlPattern="/*")
 public class EJB21Bean01 implements SessionBean
 {
 

Modified: branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/EJB21Bean02.java
===================================================================
--- branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/EJB21Bean02.java	2007-02-02 14:40:37 UTC (rev 2254)
+++ branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/EJB21Bean02.java	2007-02-02 17:33:49 UTC (rev 2255)
@@ -42,7 +42,7 @@
  */
 @WebService(name = "EndpointInterface", targetNamespace = "http://www.openuri.org/2004/04/HelloWorld", serviceName = "TestService", wsdlLocation = "META-INF/wsdl/TestService.wsdl")
 @SOAPBinding(style = SOAPBinding.Style.RPC)
- at WebContext(contextRoot="/jsr181", urlPattern="/*")
+ at WebContext(urlPattern="/*")
 public class EJB21Bean02 implements SessionBean
 {
 

Modified: branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/EJB3Bean01.java
===================================================================
--- branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/EJB3Bean01.java	2007-02-02 14:40:37 UTC (rev 2254)
+++ branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/EJB3Bean01.java	2007-02-02 17:33:49 UTC (rev 2255)
@@ -37,7 +37,7 @@
  * @since 29-Apr-2005
  */
 @WebService(name = "EndpointInterface", targetNamespace = "http://www.openuri.org/2004/04/HelloWorld", serviceName = "TestService")
- at WebContext(contextRoot="/jsr181", urlPattern="/*")
+ at WebContext(urlPattern="/*")
 @SOAPBinding(style = SOAPBinding.Style.RPC)
 @Remote(EJB3RemoteInterface.class)
 @RemoteBinding(jndiBinding = "/ejb3/EJB3EndpointInterface")

Modified: branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/EJB3Bean02.java
===================================================================
--- branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/EJB3Bean02.java	2007-02-02 14:40:37 UTC (rev 2254)
+++ branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/EJB3Bean02.java	2007-02-02 17:33:49 UTC (rev 2255)
@@ -41,7 +41,7 @@
  * @since 29-Apr-2005
  */
 @WebService(name = "EndpointInterface", targetNamespace = "http://www.openuri.org/2004/04/HelloWorld", serviceName = "TestService", wsdlLocation = "META-INF/wsdl/TestService.wsdl")
- at WebContext(contextRoot="/jsr181", urlPattern="/*")
+ at WebContext(urlPattern="/*")
 @SOAPBinding(style = SOAPBinding.Style.RPC)
 @Remote(EJB3RemoteInterface.class)
 @RemoteBinding(jndiBinding = "/ejb3/EJB3EndpointInterface")

Modified: branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/EndpointInterface03.java
===================================================================
--- branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/EndpointInterface03.java	2007-02-02 14:40:37 UTC (rev 2254)
+++ branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/EndpointInterface03.java	2007-02-02 17:33:49 UTC (rev 2255)
@@ -36,7 +36,7 @@
  * @since 29-Apr-2005
  */
 @WebService(targetNamespace = "http://foo")
- at WebContext(contextRoot="/jsr181", urlPattern="/*")
+ at WebContext(urlPattern="/*")
 @SOAPBinding(style = SOAPBinding.Style.RPC)
 public interface EndpointInterface03 extends Remote
 {

Modified: branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/JSR181WebServiceBase.java
===================================================================
--- branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/JSR181WebServiceBase.java	2007-02-02 14:40:37 UTC (rev 2254)
+++ branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/JSR181WebServiceBase.java	2007-02-02 17:33:49 UTC (rev 2255)
@@ -21,6 +21,8 @@
   */
 package org.jboss.test.ws.jaxws.samples.webservice;
 
+//$Id$
+
 import java.net.MalformedURLException;
 import java.net.URL;
 import java.rmi.RemoteException;
@@ -29,69 +31,54 @@
 import javax.xml.ws.Service;
 
 import org.jboss.test.ws.JBossWSTest;
-import org.jboss.ws.metadata.wsdl.WSDLDefinitions;
-import org.jboss.ws.tools.wsdl.WSDLDefinitionsFactory;
 
-// $Id$
-
 /**
- * Base testing class for &#064;WebService
+ * Base testing class for @WebService
  *
  * @author <a href="mailto:jason.greene at jboss.com">Jason T. Greene</a>
- * @version $Revision$
  */
 public class JSR181WebServiceBase extends JBossWSTest
 {
 
-   private EndpointInterface getPort() throws MalformedURLException
+   private EndpointInterface getPort(String context) throws MalformedURLException
    {
       QName serviceName = new QName("http://www.openuri.org/2004/04/HelloWorld", "TestService");
-      URL wsdlURL = new URL("http://" + getServerHost() + ":8080/jsr181?wsdl");
+      URL wsdlURL = new URL("http://" + getServerHost() + ":8080/" + context + "?wsdl");
 
       Service service = Service.create(wsdlURL, serviceName);
       return service.getPort(EndpointInterface.class);
    }
 
-   private EndpointInterface03 getPort03() throws MalformedURLException
+   private EndpointInterface03 getPort03(String context) throws MalformedURLException
    {
       QName serviceName = new QName("http://foo", "TestService");
-      URL wsdlURL = new URL("http://" + getServerHost() + ":8080/jsr181?wsdl");
+      URL wsdlURL = new URL("http://" + getServerHost() + ":8080/" + context + "?wsdl");
 
       Service service = Service.create(wsdlURL, serviceName);
       return service.getPort(EndpointInterface03.class);
    }
 
-   private void sayHello() throws RemoteException, MalformedURLException
+   private void sayHello(String context) throws RemoteException, MalformedURLException
    {
-      assertWSDLAccess();
       String helloWorld = "Hello world!";
-      Object retObj = getPort().echo(helloWorld);
+      Object retObj = getPort(context).echo(helloWorld);
       assertEquals(helloWorld, retObj);
    }
 
-   public void webServiceTest() throws Exception
+   public void webServiceTest(String context) throws Exception
    {
-      sayHello();
+      sayHello(context);
    }
 
-   public void webServiceWsdlLocationTest() throws Exception
+   public void webServiceWsdlLocationTest(String context) throws Exception
    {
-      sayHello();
+      sayHello(context);
    }
 
-   public void webServiceEndpointInterfaceTest() throws Exception
+   public void webServiceEndpointInterfaceTest(String context) throws Exception
    {
-      assertWSDLAccess();
       String helloWorld = "Hello Interface!";
-      Object retObj = getPort03().echo(helloWorld);
+      Object retObj = getPort03(context).echo(helloWorld);
       assertEquals(helloWorld, retObj);
    }
-
-   private void assertWSDLAccess() throws MalformedURLException
-   {
-      URL wsdlURL = new URL("http://" + getServerHost() + ":8080/jsr181?wsdl");
-      WSDLDefinitionsFactory factory = WSDLDefinitionsFactory.newInstance();
-      WSDLDefinitions wsdlDefinitions = factory.parse(wsdlURL);
-      assertNotNull(wsdlDefinitions);
-   }
 }
\ No newline at end of file

Modified: branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/JSR181WebServiceEJB3TestCase.java
===================================================================
--- branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/JSR181WebServiceEJB3TestCase.java	2007-02-02 14:40:37 UTC (rev 2254)
+++ branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/JSR181WebServiceEJB3TestCase.java	2007-02-02 17:33:49 UTC (rev 2255)
@@ -64,7 +64,7 @@
       deploy("jaxws-samples-webservice01-ejb3.jar");
       try
       {
-         webServiceTest();
+         webServiceTest("jaxws-samples-webservice01-ejb3");
       }
       finally
       {
@@ -77,7 +77,7 @@
       deploy("jaxws-samples-webservice02-ejb3.jar");
       try
       {
-         webServiceWsdlLocationTest();
+         webServiceWsdlLocationTest("jaxws-samples-webservice02-ejb3");
       }
       finally
       {
@@ -90,7 +90,7 @@
       deploy("jaxws-samples-webservice03-ejb3.jar");
       try
       {
-         webServiceEndpointInterfaceTest();
+         webServiceEndpointInterfaceTest("jaxws-samples-webservice03-ejb3");
       }
       finally
       {

Modified: branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/JSR181WebServiceJSETestCase.java
===================================================================
--- branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/JSR181WebServiceJSETestCase.java	2007-02-02 14:40:37 UTC (rev 2254)
+++ branches/jbossws-1.2.0/jbossws-tests/src/main/java/org/jboss/test/ws/jaxws/samples/webservice/JSR181WebServiceJSETestCase.java	2007-02-02 17:33:49 UTC (rev 2255)
@@ -44,7 +44,7 @@
       deploy("jaxws-samples-webservice01-jse.war");
       try
       {
-         webServiceTest();
+         webServiceTest("jaxws-samples-webservice01-jse");
       }
       finally
       {
@@ -57,7 +57,7 @@
       deploy("jaxws-samples-webservice02-jse.war");
       try
       {
-         webServiceWsdlLocationTest();
+         webServiceWsdlLocationTest("jaxws-samples-webservice02-jse");
       }
       finally
       {
@@ -70,7 +70,7 @@
       deploy("jaxws-samples-webservice03-jse.war");
       try
       {
-         webServiceEndpointInterfaceTest();
+         webServiceEndpointInterfaceTest("jaxws-samples-webservice03-jse");
       }
       finally
       {

Deleted: branches/jbossws-1.2.0/jbossws-tests/src/main/resources/jaxrpc/wsse/keystore.password
===================================================================
(Binary files differ)

Modified: branches/jbossws-1.2.0/jbossws-tests/src/main/resources/jaxrpc/wsse/store-pass-encrypt-class-cmd/jboss-wsse-server.xml
===================================================================
--- branches/jbossws-1.2.0/jbossws-tests/src/main/resources/jaxrpc/wsse/store-pass-encrypt-class-cmd/jboss-wsse-server.xml	2007-02-02 14:40:37 UTC (rev 2254)
+++ branches/jbossws-1.2.0/jbossws-tests/src/main/resources/jaxrpc/wsse/store-pass-encrypt-class-cmd/jboss-wsse-server.xml	2007-02-02 17:33:49 UTC (rev 2255)
@@ -2,10 +2,10 @@
 <jboss-ws-security xmlns="http://www.jboss.com/ws-security/config" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://www.jboss.com/ws-security/config http://www.jboss.com/ws-security/schema/jboss-ws-security_1_0.xsd">
   <key-store-file>WEB-INF/wsse.keystore</key-store-file>
   <!--Note ${buildpath} will be replaced with the actual build directory path -->
-  <key-store-password>{EXT}java -cp ${buildpath}/classes org.jboss.test.ws.jaxrpc.wsse.PasswordUtil ${buildpath}/resources/jaxrpc/wsse/keystore.password</key-store-password>
+  <key-store-password>{EXT}java -cp ${buildpath}/classes org.jboss.test.ws.jaxrpc.wsse.PasswordUtil ${buildpath}/resources/jaxrpc/samples/wssecurity/keystore.password</key-store-password>
   <trust-store-file>WEB-INF/wsse.truststore</trust-store-file>
   <!--Note ${buildpath} will be replaced with the actual build directory path -->
-  <trust-store-password>{CLASS}org.jboss.security.plugins.FilePassword:${buildpath}/resources/jaxrpc/wsse/keystore.password</trust-store-password>
+  <trust-store-password>{CLASS}org.jboss.security.plugins.FilePassword:${buildpath}/resources/jaxrpc/samples/wssecurity/keystore.password</trust-store-password>
   <config>
     <sign type="x509v3" alias="wsse"/>
     <encrypt type="x509v3" alias="wsse"/>

Deleted: branches/jbossws-1.2.0/jbossws-tests/src/main/resources/jaxrpc/wsse/wsse.keystore
===================================================================
(Binary files differ)

Deleted: branches/jbossws-1.2.0/jbossws-tests/src/main/resources/jaxrpc/wsse/wsse.truststore
===================================================================
(Binary files differ)

Deleted: branches/jbossws-1.2.0/jbossws-tests/src/main/resources/jaxws/samples/webservice/WEB-INF01/jboss-web.xml
===================================================================
--- branches/jbossws-1.2.0/jbossws-tests/src/main/resources/jaxws/samples/webservice/WEB-INF01/jboss-web.xml	2007-02-02 14:40:37 UTC (rev 2254)
+++ branches/jbossws-1.2.0/jbossws-tests/src/main/resources/jaxws/samples/webservice/WEB-INF01/jboss-web.xml	2007-02-02 17:33:49 UTC (rev 2255)
@@ -1,6 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-
-<jboss-web>
-  <context-root>/jsr181</context-root>
-</jboss-web>
-

Deleted: branches/jbossws-1.2.0/jbossws-tests/src/main/resources/jaxws/samples/webservice/WEB-INF02/jboss-web.xml
===================================================================
--- branches/jbossws-1.2.0/jbossws-tests/src/main/resources/jaxws/samples/webservice/WEB-INF02/jboss-web.xml	2007-02-02 14:40:37 UTC (rev 2254)
+++ branches/jbossws-1.2.0/jbossws-tests/src/main/resources/jaxws/samples/webservice/WEB-INF02/jboss-web.xml	2007-02-02 17:33:49 UTC (rev 2255)
@@ -1,6 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-
-<jboss-web>
-  <context-root>/jsr181</context-root>
-</jboss-web>
-

Deleted: branches/jbossws-1.2.0/jbossws-tests/src/main/resources/jaxws/samples/webservice/WEB-INF03/jboss-web.xml
===================================================================
--- branches/jbossws-1.2.0/jbossws-tests/src/main/resources/jaxws/samples/webservice/WEB-INF03/jboss-web.xml	2007-02-02 14:40:37 UTC (rev 2254)
+++ branches/jbossws-1.2.0/jbossws-tests/src/main/resources/jaxws/samples/webservice/WEB-INF03/jboss-web.xml	2007-02-02 17:33:49 UTC (rev 2255)
@@ -1,6 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-
-<jboss-web>
-  <context-root>/jsr181</context-root>
-</jboss-web>
-

Modified: branches/jbossws-1.2.0/jbossws-tests/src/main/resources/tests-tomcat-excludes.txt
===================================================================
--- branches/jbossws-1.2.0/jbossws-tests/src/main/resources/tests-tomcat-excludes.txt	2007-02-02 14:40:37 UTC (rev 2254)
+++ branches/jbossws-1.2.0/jbossws-tests/src/main/resources/tests-tomcat-excludes.txt	2007-02-02 17:33:49 UTC (rev 2255)
@@ -11,6 +11,7 @@
 org/jboss/test/ws/jaxws/samples/handlerchain/HandlerChainClientTestCase.*
 org/jboss/test/ws/jaxws/samples/jsr181ejb/**
 org/jboss/test/ws/jaxws/samples/retail/**
+org/jboss/test/ws/jaxws/samples/webservice/JSR181WebServiceEJB3TestCase.*
 org/jboss/test/ws/jaxws/samples/webserviceref/**
 
 # JBoss excludes
@@ -23,3 +24,7 @@
 # [JBWS-1471] - Remove unwanted tomcat excludes
 org/jboss/test/ws/jaxrpc/samples/wssecurity/StorePassEncryptTestCase.*
 org/jboss/test/ws/jaxws/samples/wseventing/**
+
+# [JBWS-1503] - Support XOP samples in tomcat
+org/jboss/test/ws/jaxrpc/samples/xop/**
+org/jboss/test/ws/jaxws/samples/xop/**




More information about the jbossws-commits mailing list
--- branches/jbossws-1.2.0/jbossws-core/src/main/java/org/jboss/ws/core/jaxws/WebServiceContextJSE.java	2007-02-02 14:40:37 UTC (rev 2254)
+++ branches/jbossws-1.2.0/jbossws-core/src/main/java/org/jboss/ws/core/jaxws/WebServiceContextJSE.java	2007-02-02 17:33:49 UTC (rev 2255)
@@ -24,20 +24,15 @@
 // $Id$
 
 import java.security.Principal;
-import java.util.HashSet;
-import java.util.Set;
 
-import javax.naming.InitialContext;
-import javax.naming.NamingException;
+import javax.servlet.http.HttpServletRequest;
 import javax.xml.ws.handler.MessageContext;
 
 import org.jboss.logging.Logger;
-import org.jboss.security.RealmMapping;
-import org.jboss.security.SecurityAssociation;
-import org.jboss.security.SimplePrincipal;
+import org.jboss.ws.core.jaxws.handler.MessageContextJAXWS;
 
 /**
  * A WebServiceContext implementation that delegates to jbosssx.
  *
  * @author Thomas.Diesler at jboss.org
  * @since 23-Jan-2007
@@ -47,50 +42,27 @@
    // provide logging
    private Logger log = Logger.getLogger(WebServiceContextJSE.class);
 
-   private RealmMapping realmMapping;
+   private HttpServletRequest httpRequest;
 
    public WebServiceContextJSE(MessageContext messageContext)
    {
       super(messageContext);
+      httpRequest = (HttpServletRequest)messageContext.get(MessageContextJAXWS.SERVLET_REQUEST);
+      if (httpRequest == null)
+         throw new IllegalStateException("Cannot obtain HTTPServletRequest from message context");
    }
 
    @Override
    public Principal getUserPrincipal()
    {
-      Principal principal = SecurityAssociation.getCallerPrincipal();
+      Principal principal = httpRequest.getUserPrincipal();
       return principal;
    }
 
    @Override
    public boolean isUserInRole(String role)
    {
-      boolean isUserInRole = false;
-      Principal principal = SecurityAssociation.getCallerPrincipal();
-      RealmMapping realmMapping = getRealmMapping();
-      if (realmMapping != null && principal != null)
-      {
-         Set<Principal> roles = new HashSet<Principal>();
-         roles.add(new SimplePrincipal(role));
-         isUserInRole = realmMapping.doesUserHaveRole(principal, roles);
-      }
+      boolean isUserInRole = httpRequest.isUserInRole(role);
       return isUserInRole;
    }
-
-   private RealmMapping getRealmMapping()
-   {
-      if (realmMapping == null)
-      {
-         String lookupName = "java:comp/env/security/realmMapping";
-         try
-         {
-            InitialContext iniCtx = new InitialContext();
-            realmMapping = (RealmMapping)iniCtx.lookup(lookupName);
-         }
-         catch (NamingException e)
-         {
-            log.debug("Cannot obtain realm mapping from: " + lookupName);
-         }
-      }
-      return realmMapping;
-   }
 }
@@ -24,20 +24,15 @@
 
 /**
- * A WebServiceContext implementation that delegates to jbosssx.
+ * A WebServiceContext implementation that delegates to the HttpServletRequest.
  *
  * @author Thomas.Diesler at jboss.org

Modified: branches/jbossws-1.2.0/jbossws-core/src/main/resources/samples/ant-import/build-thirdparty.xml
===================================================================